@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2005-2007, Scientific Computing Associates, Inc.
+# Copyright (c) 2005-2008, REvolution Computing, Inc.
 #
 # NetWorkSpaces is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License as published
@@ -87,10 +87,8 @@ workerLoop <- function(nws, displayName, rank, workerCount, verbose, userNws) {
   ## set RNG seed to a pseudo-unique value
   ## FIXME: Use sprng instead!
   setRNGSeed <- function() {
-    now <- as.numeric(Sys.time())
-    seedval <- as.integer(rank)
+    seedval <- as.integer(rank) + 1
     set.seed(seedval)
-    seedval
   }
 
   setRNGSeed()
